@@ -225,7 +225,7 @@ class TaggedQuerySet(models.query.QuerySet):
 
             return obj
 
-    def get_or_create(self, **kwargs):
+    def get_or_create(self, defaults=None, **kwargs):
         # Get or create object as normal
         safe_fields, singletag_fields, tag_fields = _split_kwargs(self.model, kwargs)
 
@@ -235,7 +235,7 @@ class TaggedQuerySet(models.query.QuerySet):
 
         # Use normal get_or_create if there are no tag fields
         if len(tag_fields) == 0:
-            return super(TaggedQuerySet, self).get_or_create(**safe_fields)
+            return super(TaggedQuerySet, self).get_or_create(defaults, **safe_fields)
 
         # Try to find it using get - that is able to handle tag_fields
         try:
@@ -261,6 +261,35 @@ class TaggedQuerySet(models.query.QuerySet):
 
         return queryset
 
+    def similarly_tagged(self, instance, field_name):
+        """
+        Filter the queryset to objects which are similarly tagged to the specified model
+        instance.
+
+        Arguments:
+            instance    Instance of the model whose tags we're comparing to
+            field_name  Name of TagField where we're checking similarity
+        """
+        # Start with a queryset of the tagged model, excluding the instance
+        qs = self.exclude(pk=instance.pk)
+
+        # Annotate with count of similarly tagged
+        q_filter = {f"{field_name}__in": getattr(instance, field_name).all()}
+        similar = qs.annotate(
+            tagulous_similarity=models.Count(
+                field_name, models.Q(**q_filter), distinct=True,
+            )
+        )
+
+        # Exclude any zero matches
+        similar = similar.exclude(tagulous_similarity=0)
+
+        # Order by similarity with most similar first
+        ordering = ["-tagulous_similarity"] + list(similar.model._meta.ordering)
+        similar = similar.order_by(*ordering)
+
+        return similar
+
 
 # ##############################################################################
 # ############################################################## TaggedManager
@@ -307,6 +336,9 @@ class TaggedManager(models.Manager):
 
         return manager
 
+    def similarly_tagged(self, instance, field_name):
+        return self.get_queryset().similarly_tagged(instance, field_name)
+
 
 # ##############################################################################
 # ############################################################## TaggedModel
